@@ -18,17 +18,23 @@ __examples1__ = {
     'enc(whitespace|whitespaces)':             {'test': "\t   \t \t\t\t  \t\t \t \t   \t\t  \t   \t \t\t"},
     'enc(whitespace-inv|whitespace_inverted)': {'test': " \t\t\t \t   \t\t  \t \t \t\t\t  \t\t \t\t\t \t  "},
 }
+__guess1__ = ["whitespace", "whitespace-inv"]
+__guess2__ = ["whitespace+after-before", "whitespace-after+before"]
 
 
 ENCMAP = {r'': {'0': "\t", '1': " "}, r'[-_]inv(erted)?': {'0': " ", '1': "\t"}}
-add_map("whitespace", ENCMAP, intype="bin", pattern=r"^whitespaces?([-_]inv(?:erted)?)?$", examples=__examples1__)
+add_map("whitespace", ENCMAP, intype="bin", pattern=r"^whitespaces?([-_]inv(?:erted)?)?$", examples=__examples1__,
+        guess=__guess1__)
 
 
 def wsba_encode(p):
     eq = "ord(c)" + p
     def encode(text, errors="strict"):
         r = []
-        for c in text:
+        for i, c in enumerate(text):
+            if ord(c) < min(ord(c) for c in printable[:-6]):
+                r.append(handle_error("whitespace" + p, errors, repl_char="\x00")(c, i))
+                continue
             enc = "\x00"
             offset = random.randint(-10,10)
             while enc not in printable[:-6]:
@@ -57,6 +63,6 @@ def wsba_decode(p):
 
 
 op = r"[+-](?:\d+(?:\.\d+)?[*/])?"
-add("whitespace_after_before", wsba_encode, wsba_decode,
+add("whitespace_after_before", wsba_encode, wsba_decode, guess=__guess2__,
     pattern=r"whitespace("+op+r"before"+op+r"after|"+op+r"after"+op+r"before)$")
 
